Documentation
¶
Overview ¶
Package web provides HTTP service, routing, and embedded resources for the Web interface.
Pholcus is a high-concurrency, distributed, heavyweight crawler written in pure Go. It supports standalone, server, and client modes with Web, GUI, and CLI interfaces. Web UI package.
Index ¶
- Variables
- func Flag()
- func Router()
- func Run()
- type LogSocketController
- type SocketController
- func (sc *SocketController) Add(sessID string, conn *ws.Conn)
- func (sc *SocketController) GetConn(sessID string) *ws.Conn
- func (sc *SocketController) GetWchan(sessID string) *Wchan
- func (sc *SocketController) Remove(sessID string, conn *ws.Conn)
- func (sc *SocketController) Write(sessID string, void map[string]interface{}, to ...int)
- type Wchan
Constants ¶
This section is empty.
Variables ¶
var ( // LogSocketCtrl is the global LogSocketController for log streaming. LogSocketCtrl = new(LogSocketController) )
var ( // WSController is the global SocketController for WebSocket API connections. WSController = &SocketController{ connPool: make(map[string]*ws.Conn), wchanPool: make(map[string]*Wchan), } )
Functions ¶
Types ¶
type LogSocketController ¶
type LogSocketController struct {
// contains filtered or unexported fields
}
LogSocketController manages WebSocket connections for log streaming.
func (*LogSocketController) Remove ¶
func (lsc *LogSocketController) Remove(sessID string)
type SocketController ¶
type SocketController struct {
// contains filtered or unexported fields
}
SocketController manages WebSocket connections and message channels.
func (*SocketController) GetWchan ¶
func (sc *SocketController) GetWchan(sessID string) *Wchan
Click to show internal directories.
Click to hide internal directories.